@@ -672,15 +672,21 @@ def test_getOrCreateByNum(iface_with_nodes):
 @pytest.mark.unit
 def test_exit_with_exception(caplog):
     """Test __exit__()"""
-    iface = MeshInterface(noProto=True)
     with caplog.at_level(logging.ERROR):
-        iface.__exit__("foo", "bar", "baz")
-        assert re.search(
-            r"An exception of type foo with value bar has occurred",
-            caplog.text,
-            re.MULTILINE,
-        )
-        assert re.search(r"Traceback: baz", caplog.text, re.MULTILINE)
+        try:
+            with MeshInterface(noProto=True):
+                raise ValueError("Something went wrong")
+        except:
+            assert re.search(
+                r"An exception of type <class \'ValueError\'> with value Something went wrong has occurred",
+                caplog.text,
+                re.MULTILINE,
+            )
+            assert re.search(
+                r"Traceback:\n.*in test_exit_with_exception\n {4}raise ValueError\(\"Something went wrong\"\)",
+                caplog.text,
+                re.MULTILINE
+            )
 
 
 @pytest.mark.unit
