@@ -26,10 +26,11 @@ from meshtastic.protobuf import portnums_pb2
 from meshtastic import mt_config
 from meshtastic.util import ipstr, readnet_u16
 
+logger = logging.getLogger(__name__)
 
 def onTunnelReceive(packet, interface):  # pylint: disable=W0613
     """Callback for received tunneled messages from mesh."""
-    logging.debug(f"in onTunnelReceive()")
+    logger.debug(f"in onTunnelReceive()")
     tunnelInstance = mt_config.tunnelInstance
     tunnelInstance.onReceive(packet)
 
@@ -92,7 +93,7 @@ class Tunnel:
         self.LOG_TRACE = 5
 
         # TODO: check if root?
-        logging.info(
+        logger.info(
             "Starting IP to mesh tunnel (you must be root for this *pre-alpha* "
             "feature to work).  Mesh members:"
         )
@@ -104,13 +105,13 @@ class Tunnel:
             for node in self.iface.nodes.values():
                 nodeId = node["user"]["id"]
                 ip = self._nodeNumToIp(node["num"])
-                logging.info(f"Node { nodeId } has IP address { ip }")
+                logger.info(f"Node { nodeId } has IP address { ip }")
 
-        logging.debug("creating TUN device with MTU=200")
+        logger.debug("creating TUN device with MTU=200")
         # FIXME - figure out real max MTU, it should be 240 - the overhead bytes for SubPacket and Data
         self.tun = None
         if self.iface.noProto:
-            logging.warning(
+            logger.warning(
                 f"Not creating a TapDevice() because it is disabled by noProto"
             )
         else:
@@ -120,11 +121,11 @@ class Tunnel:
 
         self._rxThread = None
         if self.iface.noProto:
-            logging.warning(
+            logger.warning(
                 f"Not starting TUN reader because it is disabled by noProto"
             )
         else:
-            logging.debug(f"starting TUN reader, our IP address is {myAddr}")
+            logger.debug(f"starting TUN reader, our IP address is {myAddr}")
             self._rxThread = threading.Thread(
                 target=self.__tunReader, args=(), daemon=True
             )
@@ -134,9 +135,9 @@ class Tunnel:
         """onReceive"""
         p = packet["decoded"]["payload"]
         if packet["from"] == self.iface.myInfo.my_node_num:
-            logging.debug("Ignoring message we sent")
+            logger.debug("Ignoring message we sent")
         else:
-            logging.debug(f"Received mesh tunnel message type={type(p)} len={len(p)}")
+            logger.debug(f"Received mesh tunnel message type={type(p)} len={len(p)}")
             # we don't really need to check for filtering here (sender should have checked),
             # but this provides useful debug printing on types of packets received
             if not self.iface.noProto:
@@ -152,7 +153,7 @@ class Tunnel:
         ignore = False  # Assume we will be forwarding the packet
         if protocol in self.protocolBlacklist:
             ignore = True
-            logging.log(
+            logger.log(
                 self.LOG_TRACE, f"Ignoring blacklisted protocol 0x{protocol:02x}"
             )
         elif protocol == 0x01:  # ICMP
@@ -160,7 +161,7 @@ class Tunnel:
             icmpCode = p[21]
             checksum = p[22:24]
             # pylint: disable=line-too-long
-            logging.debug(
+            logger.debug(
                 f"forwarding ICMP message src={ipstr(srcaddr)}, dest={ipstr(destAddr)}, type={icmpType}, code={icmpCode}, checksum={checksum}"
             )
             # reply to pings (swap src and dest but keep rest of packet unchanged)
@@ -171,19 +172,19 @@ class Tunnel:
             destport = readnet_u16(p, subheader + 2)
             if destport in self.udpBlacklist:
                 ignore = True
-                logging.log(self.LOG_TRACE, f"ignoring blacklisted UDP port {destport}")
+                logger.log(self.LOG_TRACE, f"ignoring blacklisted UDP port {destport}")
             else:
-                logging.debug(f"forwarding udp srcport={srcport}, destport={destport}")
+                logger.debug(f"forwarding udp srcport={srcport}, destport={destport}")
         elif protocol == 0x06:  # TCP
             srcport = readnet_u16(p, subheader)
             destport = readnet_u16(p, subheader + 2)
             if destport in self.tcpBlacklist:
                 ignore = True
-                logging.log(self.LOG_TRACE, f"ignoring blacklisted TCP port {destport}")
+                logger.log(self.LOG_TRACE, f"ignoring blacklisted TCP port {destport}")
             else:
-                logging.debug(f"forwarding tcp srcport={srcport}, destport={destport}")
+                logger.debug(f"forwarding tcp srcport={srcport}, destport={destport}")
         else:
-            logging.warning(
+            logger.warning(
                 f"forwarding unexpected protocol 0x{protocol:02x}, "
                 "src={ipstr(srcaddr)}, dest={ipstr(destAddr)}"
             )
@@ -192,10 +193,10 @@ class Tunnel:
 
     def __tunReader(self):
         tap = self.tun
-        logging.debug("TUN reader running")
+        logger.debug("TUN reader running")
         while True:
             p = tap.read()
-            # logging.debug(f"IP packet received on TUN interface, type={type(p)}")
+            # logger.debug(f"IP packet received on TUN interface, type={type(p)}")
             destAddr = p[16:20]
 
             if not self._shouldFilterPacket(p):
@@ -210,7 +211,7 @@ class Tunnel:
 
         for node in self.iface.nodes.values():
             nodeNum = node["num"] & 0xFFFF
-            # logging.debug(f"Considering nodenum 0x{nodeNum:x} for ipBits 0x{ipBits:x}")
+            # logger.debug(f"Considering nodenum 0x{nodeNum:x} for ipBits 0x{ipBits:x}")
             if (nodeNum) == ipBits:
                 return node["user"]["id"]
         return None
@@ -222,12 +223,12 @@ class Tunnel:
         """Forward the provided IP packet into the mesh"""
         nodeId = self._ipToNodeId(destAddr)
         if nodeId is not None:
-            logging.debug(
+            logger.debug(
                 f"Forwarding packet bytelen={len(p)} dest={ipstr(destAddr)}, destNode={nodeId}"
             )
             self.iface.sendData(p, nodeId, portnums_pb2.IP_TUNNEL_APP, wantAck=False)
         else:
-            logging.warning(
+            logger.warning(
                 f"Dropping packet because no node found for destIP={ipstr(destAddr)}"
             )
 
